@@ -32,67 +32,104 @@ AthenaListObjectTypes <- function(connection) {
   UseMethod("AthenaListObjectTypes")
 }
 
+#' @export
 AthenaListObjectTypes.default <- function(connection) {
-  # slurp all the objects in the database so we can determine the correct
+  # slurp all the objects in the schema so we can determine the correct
   # object hierarchy
-  
-  # all databases contain tables, at a minimum
+
+  # all schema contain tables, at a minimum
   obj_types <- list(table = list(contains = "data"))
-  
+
   # see if we have views too
   table_types <- AthenaTableTypes(connection)
   if (any(grepl("VIEW", table_types))) {
     obj_types <- c(obj_types, list(view = list(contains = "data")))
   }
-  
-  # check for multiple database or a named database
-  databases <- AthenaDatabase(connection)
-  if (length(databases) > 1) {
-    obj_types <- list(database = list(contains = obj_types))
+
+  # check for multiple schema or a named schema
+  schemas <- AthenaDatabase(connection, connection@info[["db.catalog"]])
+  if (length(schemas) > 0) {
+    obj_types <- list(schema = list(contains = obj_types))
   }
-  
-  return(obj_types)
+
+  catalogs <- list_catalogs(connection@ptr$Athena)
+  # check for multiple catalogs
+  if (length(catalogs) > 0) {
+    obj_types <- list(catalog = list(contains = obj_types))
+  }
+
+  obj_types
 }
 
-# List objects in a connection.
-#
-# Lists all of the objects in the connection, or all the objects which have
-# specific attributes.
-#
-# When used without parameters, this function returns all of the objects known
-# by the connection. Any parameters passed will filter the list to only objects
-# which have the given attributes; for instance, passing \code{database = "foo"}
-# will return only objects matching the database \code{foo}.
-#
-# @param connection A connection object, as returned by `dbConnect()`.
-# @param ... Attributes to filter by.
-# @return A data frame with \code{name} and \code{type} columns, listing the
-#   objects.
+#' List objects in a connection.
+#'
+#' Lists all of the objects in the connection, or all the objects which have
+#' specific attributes.
+#'
+#' When used without parameters, this function returns all of the objects known
+#' by the connection. Any parameters passed will filter the list to only objects
+#' which have the given attributes; for instance, passing \code{schema = "foo"}
+#' will return only objects matching the schema \code{foo}.
+#'
+#' @param connection A connection object, as returned by `dbConnect()`.
+#' @param ... Attributes to filter by.
+#' @return A data frame with \code{name} and \code{type} columns, listing the
+#'   objects.
+#' @keywords internal
+#' @export
+AthenaListObjects <- function(connection, ...) {
+  UseMethod("AthenaListObjects")
+}
 
-AthenaListObjects <- function(connection, ...) {UseMethod("AthenaListObjects")}
-
-AthenaListObjects.default <- function(connection, database = NULL, name = NULL, ...) {
-  
-  # if no database was supplied but this database has database, return a list of
-  # database
-  if (is.null(database)) {
-    database <- AthenaDatabase(connection)
-    if (length(database) > 1) {
+#'@export
+AthenaListObjects.AthenaConnection <- function(
+  connection,
+  catalog = NULL,
+  schema = NULL,
+  name = NULL,
+  ...
+) {
+  # if no catalog was supplied but this database has catalogs, return a list of
+  # catalogs
+  if (is.null(catalog)) {
+    catalogs <- list_catalogs(connection@ptr$Athena)
+    if (length(catalogs) > 0) {
       return(
         data.frame(
-          name = database,
-          type = rep("database", times = length(database)),
+          name = catalogs,
+          type = rep("catalog", times = length(catalogs)),
           stringsAsFactors = FALSE
-        ))
+        )
+      )
     }
   }
-  
-  objs <- AthenaTableTypes(connection, database= database, name = name)
+
+  # if no schema was supplied but this catalog has schema, return a list of
+  # schema
+  if (is.null(schema)) {
+    schema <- AthenaDatabase(connection, catalog)
+    if (length(schema) > 0) {
+      return(
+        data.frame(
+          name = schema,
+          type = rep("schema", times = length(schema)),
+          stringsAsFactors = FALSE
+        )
+      )
+    }
+  }
+
+  objs <- AthenaTableTypes(
+    connection,
+    catalog = catalog,
+    schema = schema,
+    name = name
+  )
   # just return a list of the objects and their types, possibly filtered by the
   # options above
   data.frame(
     name = names(objs),
-    type = gsub(".*_", "", unname(tolower(objs))),
+    type = gsub(".* ", "", unname(tolower(objs))),
     stringsAsFactors = FALSE
   )
 }
@@ -112,11 +149,14 @@ AthenaListObjects.default <- function(connection, database = NULL, name = NULL,
 
 # given a connection, returns its "host name" (a unique string which identifies it)
 computeHostName <- function(connection) {
-  paste(collapse = "_",c(
-    connection@info$profile_name,
-    "Athena",
-    connection@ptr$region_name
-  ))
+  paste(
+    collapse = "_",
+    c(
+      connection@info$profile_name,
+      "Athena",
+      connection@ptr$region_name
+    )
+  )
 }
 
 computeDisplayName <- function(connection) {
@@ -125,38 +165,44 @@ computeDisplayName <- function(connection) {
 
 # selects the table or view from arguments
 validateObjectName <- function(table, view) {
-  
   # Error if both table and view are passed
   if (!is.null(table) && !is.null(view)) {
     stop("`table` and `view` can not both be used", call. = FALSE)
   }
-  
+
   # Error if neither table and view are passed
   if (is.null(table) && is.null(view)) {
     stop("`table` and `view` can not both be `NULL`", call. = FALSE)
   }
-  
+
   return(table %||% view)
 }
 
 AthenaListColumns <- function(connection, ...) UseMethod("AthenaListColumns")
 
-AthenaListColumns.default <- function(connection,
-                                      table = NULL,
-                                      view = NULL,
-                                      database = NULL,
-                                      ...) {
+#' @export
+AthenaListColumns.AthenaConnection <- function(
+  connection,
+  table = NULL,
+  view = NULL,
+  catalog = NULL,
+  schema = NULL,
+  ...
+) {
   if (dbIsValid(connection)) {
-    glue <- connection@ptr$glue
-    tryCatch({
-      output <- py_to_r(glue$get_table(
-        DatabaseName = database, Name = table %||% view)$Table
-      )
-    }, error = function(e) py_error(e)
+    athena <- connection@ptr$Athena
+
+    output <- py_to_r(
+      athena$get_table_metadata(
+        CatalogName = catalog,
+        DatabaseName = schema,
+        TableName = table %||% view
+      )$TableMetadata
     )
-    col_names <- sapply(output$StorageDescriptor$Columns, ColMeta)
+
+    col_names <- sapply(output$Columns, ColMeta)
     partition <- unlist(sapply(output$PartitionKeys, ColMeta))
-    
+
     tbl_meta <- c(col_names, partition)
     data.frame(
       name = names(tbl_meta),
@@ -168,63 +214,108 @@ AthenaListColumns.default <- function(connection,
   }
 }
 
-AthenaTableTypes <- function(connection, database = NULL, name = NULL, ...) {
+AthenaTableTypes <- function(
+  connection,
+  catalog = NULL,
+  schema = NULL,
+  name = NULL,
+  ...
+) {
   con_error_msg(connection, "Connection already closed.")
-  glue <- connection@ptr$glue
-  if(is.null(database)) 
-    database <- unlist(get_databases(glue))
-  if(is.null(name)){
-    tryCatch({
-      output <- lapply(database, function(i) get_table_list(glue = glue, schema = i))
-    }, error = function(cond) NULL)
-    tbl_meta <- sapply(unlist(output, recursive = F), function(x) TblMeta(x))
+  athena <- connection@ptr$Athena
+
+  if (is.null(catalog)) {
+    catalog <- list_catalogs(athena)
+  }
+
+  if (is.null(schema)) {
+    schema <- unlist(lapply(catalog, function(ct) list_schemas(athena, ct)))
+  }
+
+  if (is.null(name)) {
+    cat_filter <- ""
+    db_filter <- ""
+    cat_filter <- sprintf(
+      "and lower(table_catalog) in ('%s')",
+      paste(tolower(catalog), collapse = "', '")
+    )
+    db_filter <- sprintf(
+      "and lower(table_schema) in ('%s')",
+      paste(tolower(schema), collapse = "', '")
+    )
+    query <- "select
+      table_name as TableName,
+      table_type as TableType
+    from information_schema.tables
+    where table_schema != 'information_schema' %s %s
+    order by table_catalog, table_schema
+    "
+    output <- suppressMessages(
+      dbGetQuery(connection, sprintf(query, cat_filter, db_filter))
+    )
+    tbl_meta <- output[["TableType"]]
+    names(tbl_meta) <- output[["TableName"]]
   } else {
-    tryCatch({
-      output <- py_to_r(glue$get_table(DatabaseName = database, Name = name)$Table)
-    }, error = function(e) py_error(e))
+    output <- py_to_r(
+      athena$get_table_metadata(
+        CatalogName = catalog,
+        DatabaseName = schema,
+        TableName = name
+      )$TableMetadata
+    )
     tbl_meta <- output$TableType
-    names(tbl_meta) <- output$Name}
+    names(tbl_meta) <- output$Name
+  }
   return(tbl_meta)
 }
 
-AthenaDatabase <- function(connection, ...) {
+AthenaDatabase <- function(connection, catalog, ...) {
   con_error_msg(connection, "Connection already closed.")
-  glue <- connection@ptr$glue
-  return(unlist(get_databases(glue)))
+  athena <- connection@ptr$Athena
+  return(unlist(list_schemas(athena, catalog)))
 }
 
-# Preview the data in an object.
-#
-# Return the data inside an object as a data frame.
-#
-# The object to previewed must be specified as one of the arguments
-# (e.g. \code{table = "employees"}); depending on the driver and underlying
-# data store, additional specification arguments may be required.
-#
-# @param connection A connection object, as returned by `dbConnect()`.
-# @param rowLimit The maximum number of rows to display.
-# @param ... Parameters specifying the object.
-# @return A data frame containing the data in the object.
+#' Preview the data in an object.
+#'
+#' Return the data inside an object as a data frame.
+#'
+#' The object to previewed must be specified as one of the arguments
+#' (e.g. \code{table = "employees"}); depending on the driver and underlying
+#' data store, additional specification arguments may be required.
+#'
+#' @param connection A connection object, as returned by `dbConnect()`.
+#' @param rowLimit The maximum number of rows to display.
+#' @param ... Parameters specifying the object.
+#' @return A data frame containing the data in the object.
+#' @keywords internal
+#' @export
+AthenaPreviewObject <- function(connection, rowLimit, ...) {
+  UseMethod("AthenaPreviewObject")
+}
 
-AthenaPreviewObject <- function(connection, rowLimit, ...) UseMethod("AthenaPreviewObject")
-
-AthenaPreviewObject <- function(connection,
-                                rowLimit,
-                                table = NULL,
-                                view = NULL,
-                                database = NULL,
-                                ...) {
+#' @export
+AthenaPreviewObject.AthenaConnection <- function(
+  connection,
+  rowLimit,
+  table = NULL,
+  view = NULL,
+  catalog = NULL,
+  schema = NULL,
+  ...
+) {
   # extract object name from arguments
   name <- validateObjectName(table, view)
-  
-  # prepend database if specified
-  if (!is.null(database)) {
+
+  # prepend schema if specified
+  if (!is.null(schema)) {
     name <- paste(
-      dbQuoteIdentifier(connection, database),
-      dbQuoteIdentifier(connection, name), sep = ".")
+      dbQuoteIdentifier(connection, schema),
+      dbQuoteIdentifier(connection, name),
+      sep = "."
+    )
   }
-  
-  return(dbGetQuery(connection, paste("SELECT * FROM", name, "LIMIT", rowLimit)))
+
+  dbGetQuery(connection, paste("SELECT * FROM", name, "LIMIT", rowLimit))
 }
 
 # Get an icon representing a connection.
@@ -259,7 +350,7 @@ AthenaConnectionIcon <- function(connection) {
 
 AthenaConnectionActions <- function(connection) {
   icons <- system.file(file.path("icons"), package = "RAthena")
-  
+
   actions <- list(
     "Athena" = list(
       icon = file.path(icons, "athena-logo.png"),
@@ -268,7 +359,7 @@ AthenaConnectionActions <- function(connection) {
       }
     )
   )
-  
+
   if (exists(".rs.api.documentNew")) {
     documentNew <- get(".rs.api.documentNew")
     actions <- c(
@@ -282,16 +373,21 @@ AthenaConnectionActions <- function(connection) {
               ls(envir = .GlobalEnv)
             )
             tables <- dbListTables(connection)
-            
+
             contents <- paste(
               paste("-- !preview conn=", varname, sep = ""),
               "",
-              if (length(tables) > 0)
-                paste("SELECT * FROM \"", tables[[1]], "\"\nLIMIT 100", 
-                      "\n\n-- Note: Please utilise LIMIT to restrict Data Scanned by AWS Athena",
-                      sep = "")
-              else
-                "SELECT 1",
+              if (length(tables) > 0) {
+                paste(
+                  "SELECT * FROM \"",
+                  tables[[1]],
+                  "\"\nLIMIT 100",
+                  "\n\n-- Note: Please utilise LIMIT to restrict Data Scanned by AWS Athena",
+                  sep = ""
+                )
+              } else {
+                "SELECT 1"
+              },
               "",
               sep = "\n"
             )
@@ -301,7 +397,7 @@ AthenaConnectionActions <- function(connection) {
       )
     )
   }
-  
+
   actions <- c(
     actions,
     list(
@@ -313,19 +409,21 @@ AthenaConnectionActions <- function(connection) {
       )
     )
   )
-  
+
   actions
 }
 
 on_connection_closed <- function(con) {
   # make sure we have an observer
   observer <- getOption("connectionObserver")
-  if (is.null(observer))
+  if (is.null(observer)) {
     return(invisible(NULL))
-  
-  if(!athena_option_env$rstudio_conn_tab)
+  }
+
+  if (!athena_option_env$rstudio_conn_tab) {
     return(invisible(NULL))
-  
+  }
+
   type <- "Athena"
   host <- computeHostName(con)
   observer$connectionClosed(type, host)
@@ -334,12 +432,14 @@ on_connection_closed <- function(con) {
 on_connection_updated <- function(con, hint) {
   # make sure we have an observer
   observer <- getOption("connectionObserver")
-  if (is.null(observer))
+  if (is.null(observer)) {
     return(invisible(NULL))
-  
-  if(!athena_option_env$rstudio_conn_tab)
+  }
+
+  if (!athena_option_env$rstudio_conn_tab) {
     return(invisible(NULL))
-  
+  }
+
   type <- "Athena"
   host <- computeHostName(con)
   observer$connectionUpdated(type, host, hint = hint)
@@ -348,57 +448,62 @@ on_connection_updated <- function(con, hint) {
 on_connection_opened <- function(connection) {
   # make sure we have an observer
   observer <- getOption("connectionObserver")
-  if (is.null(observer))
+  if (is.null(observer)) {
     return(invisible(NULL))
-  
-  if(!athena_option_env$rstudio_conn_tab)
+  }
+
+  if (!athena_option_env$rstudio_conn_tab) {
     return(invisible(NULL))
-  
+  }
+
   # find an icon for this DBMS
   icon <- AthenaConnectionIcon(connection)
-  
+
   # let observer know that connection has opened
   observer$connectionOpened(
     # name displayed in connection pane
     displayName = computeDisplayName(connection),
-    
+
     type = "Athena",
     # host key
     host = computeHostName(connection),
-    
+
     # icon for connection
     icon = icon,
-    
+
     # connection code
-    connectCode = paste(c("library(DBI)", "con <- dbConnect(RAthena::athena())"),collapse = "\n"),
-    
+    connectCode = paste(
+      c("library(DBI)", "con <- dbConnect(RAthena::athena())"),
+      collapse = "\n"
+    ),
+
     # disconnection code
     disconnect = function() {
       dbDisconnect(connection)
     },
-    
-    listObjectTypes = function () {
+
+    listObjectTypes = function() {
       AthenaListObjectTypes(connection)
     },
-    
+
     # table enumeration code
     listObjects = function(...) {
       AthenaListObjects(connection, ...)
     },
-    
+
     # column enumeration code
     listColumns = function(...) {
       AthenaListColumns(connection, ...)
     },
-    
+
     # table preview code
     previewObject = function(rowLimit, ...) {
       AthenaPreviewObject(connection, rowLimit, ...)
     },
-    
+
     # other actions that can be executed on this connection
     actions = AthenaConnectionActions(connection),
-    
+
     # raw connection object
     connectionObject = connection
   )
@@ -406,13 +511,13 @@ on_connection_opened <- function(connection) {
 # nocov end
 
 TblMeta <- function(x) {
-  tbl_type <- x$TableType %||% ""
+  tbl_type <- if (length(x$TableType)) x$TableType else ""
   names(tbl_type) <- x$Name
   tbl_type
 }
 
-ColMeta <- function(x){
-  col_type <- x$Type %||% ""
+ColMeta <- function(x) {
+  col_type <- if (length(x$Type)) x$Type else ""
   names(col_type) <- x$Name
   col_type
 }
