@@ -10,15 +10,20 @@ test_that("Testing if caching returns the same query id", {
   # Test connection is using AWS CLI to set profile_name 
   con <- dbConnect(athena())
   
-  res1 = dbSendStatement(con, "SELECT table_name FROM information_schema.tables limit 1")
+  query1 = "SELECT table_name FROM information_schema.tables limit 1"
+  res1 = dbSendStatement(con, query1)
   dbFetch(res1)
-  res2 = dbExecute(con, "SELECT table_name FROM information_schema.tables limit 1")
+  res2 = dbExecute(con, query1)
   
   RAthena_options(cache_size = 10)
   
-  res3 = dbSendStatement(con, "SELECT table_name FROM information_schema.tables limit 1")
+  res3 = dbSendStatement(con, query1)
   dbFetch(res3)
-  res4 = dbExecute(con, "SELECT table_name FROM information_schema.tables limit 1")
+  res4 = dbExecute(con, query1)
+  
+  query2 = "SELECT table_schema, table_name FROM information_schema.tables limit 1"
+  res5 = dbExecute(con, query2, unload = T)
+  res6 = dbExecute(con, query2)
   
   # clear cached backend data
   RAthena_options(clear_cache = T)
@@ -26,9 +31,13 @@ test_that("Testing if caching returns the same query id", {
   # expect query ids not to be the same
   exp1 = res1@info$QueryExecutionId == res2@info$QueryExecutionId
   exp2 = res3@info$QueryExecutionId == res4@info$QueryExecutionId
+  exp3 = res5@info$UnloadDir == res6@info$UnloadDir
+  exp4 = res5@info$QueryExecutionId == res6@info$QueryExecutionId
   expect_false(exp1)
   expect_true(exp2)
+  expect_true(exp3)
+  expect_true(exp4)
   expect_error(RAthena_options(cache_size = 101))
   expect_error(RAthena_options(cache_size = -1))
   expect_true(nrow(RAthena:::athena_option_env$cache_dt) == 0)
-})
\ No newline at end of file
+})
