@@ -18,7 +18,7 @@ test_that("Testing class formation", {
 
   # testing components of s4 class
   expect_identical(names(attributes(con)), c("ptr", "info", "quote","class"))
-  expect_identical(names(attributes(res)), c("connection", "athena", "info", "class"))
+  expect_identical(names(attributes(res)), c("connection", "info", "class"))
   expect_s4_class(con,"AthenaConnection")
   expect_s4_class(res,"AthenaResult")
 })
